pub fn problem_for(status: u16, payload: &[u8]) -> Option<ProblemError>Expand description
The failure the API reported, and nothing at all when what it answered was a success.
pub fn problem_for(status: u16, payload: &[u8]) -> Option<ProblemError>The failure the API reported, and nothing at all when what it answered was a success.